@@ -1,4 +1,4 @@
 # This is a relay I run on a personal server. If it gets too expensive to
 # run, I'll shut it down.
-RENDEZVOUS_RELAY = u"ws://relay.magic-wormhole.io:4000/v1"
+MAILBOX_RELAY = RENDEZVOUS_RELAY = u"ws://relay.magic-wormhole.io:4000/v1"
 TRANSIT_RELAY = u"tcp:transit.magic-wormhole.io:4001"
